@@ -17,7 +17,7 @@ class JobScheduler:
     def start(self):
         logger.info("start")
         subprocess.check_output(
-            'nohup notejob _start >>logs/jobs/notejob-run-$(date +%Y-%m-%d).log 2>&1 &', shell=True)
+            'nohup notejob _start >>/notechats/logs/jobs/notejob-run-$(date +%Y-%m-%d).log 2>&1 &', shell=True)
 
     def _start(self):
         logger.info("start")
